@@ -89,6 +89,11 @@ class RangeTestCase(unittest.TestCase):
             v = str(CronSlice(4, a))
             self.assertEqual(v, b, "%s != %s, from %s" % (v, b, a))
 
+    def test_06_backwards(self):
+        """Test backwards ranges for error"""
+        tab = CronTab(tab="* * * * 3-1 command")
+        self.assertEquals(str(tab), "* * * * 1-3 command\n")
+
 if __name__ == '__main__':
     test_support.run_unittest(
        RangeTestCase,
